# Getting Started

Example for getting data from open street map:


```python linenums="1" title="osm_service.py"
--8<-- "docs/examples/osm_service.py"
```

<!-- termynal -->
```bash
$ python osm_service.py
---> 100%
Neurüti
Engelhornhütte
Reutsperre
Dossenhütte SAC
https://www.dossenhuette.ch
Brochhütte
https://www.brochhuette.ch/
```
